# aqua-blue-hyperopt
Hyperparameter optimization library for aqua-blue models 

[![Custom shields.io](https://img.shields.io/badge/docs-brightgreen?logo=github&logoColor=green&label=gh-pages)](https://lonelyneutrin0.github.io/aqua-blue-hyperopt/)

[![PyPI version shields.io](https://img.shields.io/pypi/v/aqua-blue-hyperopt.svg)](https://pypi.python.org/pypi/aqua-blue-hyperopt/)
[![PyPI pyversions shields.io](https://img.shields.io/pypi/pyversions/aqua-blue-hyperopt.svg)](https://pypi.python.org/pypi/aqua-blue-hyperopt/)

```bash
git clone https://github.com/lonelyneutrin0/aqua_blue_hyperopt
pip install aqua-blue-hyperopt/
```

or, with dev packages, and running the CI/CD:

```bash
git clone https://github.com/lonelyneutrin0/aqua-blue-hyperopt
cd aqua-blue-hyperopt/
pip install aqua-blue-hyperopt/[dev]
pytest
ruff check aqua_blue_hyperopt/
mypy aqua_blue_hyperopt/
```
